<?php
/**
 * This file is part of the Dubas Product Category - EspoCRM extension.
 *
 * DUBAS S.C. - contact@dubas.pro
 * Copyright (C) 2022-2022 Arkadiy Asuratov, Emil Dubielecki
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

namespace Espo\Modules\DubasProductCategory\Hooks\OpportunityItem;

use Espo\ORM\Entity;
use Espo\ORM\EntityManager;

class AddProductCategory
{
    private EntityManager $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function beforeSave(Entity $entity, array $options = [])
    {
        if ($this->checkFields($entity) !== true) {
            return;
        }

        $category = null;
        $product = $this->entityManager->getEntity('Product', $entity->get('productId'));
        $categoryId = $product->get('categoryId');

        if ($categoryId) {
            $entity->set('productCategoryId', $categoryId);
        }
    }

    protected function checkFields(Entity $entity)
    {
        if (
            (
                $entity->isNew()
                ||
                $entity->isAttributeChanged('productId')
            )
            &&
            $entity->get('productId')
        ) {
            return true;
        }
    }
}
